@@ -3,11 +3,15 @@ from exco import util
 from exco import exception
 from exco.cell_location import CellLocation
 from exco.exco_template import ExcoTemplate, ExcoBlock
-from exco.extraction_spec import AssumptionSpec, \
+from exco.extractor_spec import AssumptionSpec, \
     ValidatorSpec, \
-    ExtractionTaskSpec, \
+    CellExtractionSpec, \
     LocatorSpec, \
     ExcelProcessorSpec
 
 from exco.extractor import ExcelProcessorFactory, ExcelProcessor
 from exco.shortcut import from_excel
+
+__all__ = ['version', 'util', 'exception', 'CellLocation', 'ExcoTemplate', 'ExcoBlock',
+           'AssumptionSpec', 'ValidatorSpec', 'CellExtractionSpec', 'LocatorSpec', 'ExcelProcessorSpec',
+           'ExcelProcessorFactory', 'ExcelProcessor', 'from_excel']
