@@ -11,11 +11,11 @@ class AssumptionFactory(BaseFactory[Assumption, AssumptionSpec]):
         super().__init__(class_map)
 
     @classmethod
-    def suffix(self):
+    def suffix(cls):
         return 'Assumption'
 
     @classmethod
     def default(cls) -> 'AssumptionFactory':
-        return cls(cls.build_class_dict([
+        return cls(class_map=cls.build_class_dict([
             LeftCellMatchAssumption
         ]))
