@@ -93,7 +93,7 @@ class ExcelDerefedProcessor:
             cell_results=cell_result, table_results=table_result)
 
     def process_excel(self, fname: str) -> ExcelProcessingResult:
-        wb = openpyxl.load_workbook(fname)
+        wb = openpyxl.load_workbook(fname, data_only=True)
         return self.process_workbook(wb)
 
     def __str__(self):
@@ -114,7 +114,6 @@ class ExcelProcessor:
 
     def deref(self, workbook: Optional[Workbook]) -> ExcelDerefedProcessor:
         if workbook is not None:
-            print(self.spec)
             derefed_spec = self.spec.spec_to_extractor_deref(workbook)
             return self.factory.create_derefed_processor_from_spec(derefed_spec)
         else:
@@ -124,7 +123,7 @@ class ExcelProcessor:
         return self.deref(workbook).process_workbook(workbook)
 
     def process_excel(self, fname: str) -> ExcelProcessingResult:
-        wb = openpyxl.load_workbook(fname)
+        wb = openpyxl.load_workbook(fname, data_only=True)
         return self.process_workbook(wb)
 
     def __str__(self) -> str:
@@ -163,7 +162,8 @@ class ExcelProcessorFactory:
                     spec=spec.parser),
                 validators={
                     k: self.validator_factory.create_from_spec(sp) for k, sp in spec.validations.items()},
-                fallback=spec.fallback)
+                fallback=spec.fallback,
+                metadata=spec.apv.metadata)
         except ExcoException as e:
             raise ExtractionTaskCreationException(
                 f'Unable to create ExtractionTask for {spec.key} cf {spec.source.describe()}') from e
@@ -206,7 +206,7 @@ class ExcelProcessorFactory:
 
     def create_from_template_excel(self,
                                    fname: str) -> ExcelProcessor:
-        workbook = openpyxl.load_workbook(fname)
+        workbook = openpyxl.load_workbook(fname, data_only=True)
         return self.create_from_template_workbook(workbook)
 
     def create_from_template_workbook(
