@@ -12,15 +12,17 @@ from openpyxl.worksheet.worksheet import Worksheet
 class RightOfRegexLocator(Locator):
     regex: str
 
-    def locate(self, anchor_cell_location: CellLocation, workbook: Workbook) -> LocatingResult:
+    def locate(self, anchor_cell_location: CellLocation,
+               workbook: Workbook) -> LocatingResult:
         sheet: Worksheet = workbook[anchor_cell_location.sheet_name]
         compiled_regex = re.compile(self.regex)
         for row in sheet.iter_rows():
             for cell in row:
-                if compiled_regex.fullmatch(row) is not None:
+                if compiled_regex.fullmatch(str(cell.value)) is not None:
                     cell_loc = CellLocation(
                         sheet_name=anchor_cell_location.sheet_name,
                         coordinate=util.shift_coord(cell.coordinate, (0, 1))
                     )
                     return LocatingResult.good(cell_loc)
-        return LocatingResult.bad(msg=f"Unable to find cell to the right of {self.regex}")
+        return LocatingResult.bad(
+            msg=f"Unable to find cell to the right of {self.regex}")
