@@ -11,5 +11,5 @@ class IntParser(ValueParser[int]):
     def parse_value(self, v: Any) -> int:
         try:
             return int(v)  # fix this it shouldn't parse float
-        except ValueError as e:
+        except Exception as e:
             raise ParsingFailException(f'Unable to parse {v} to int') from e
